pub struct StateSyncMessage<H>where
H: HeaderLike,{
pub header: H,
pub snapshots: Snapshot,
pub deltas: Option<BlockAggregatedChanges>,
pub removed_components: HashMap<String, ProtocolComponent>,
}Fields
header: HThe block information for this update.
snapshots: SnapshotSnapshot for new components.
deltas: Option<BlockAggregatedChanges>A single delta contains state updates for all tracked components, as well as additional information about the system components e.g. newly added components (even below tvl), tvl updates, balance updates.
removed_components: HashMap<String, ProtocolComponent>Components that stopped being tracked.
Implementations
Sourceimpl<H> StateSyncMessage<H>where
H: HeaderLike,
impl<H> StateSyncMessage<H>where
H: HeaderLike,